//
//  DetailViewController.m
//  Dailymotion Demo
//
//  Created by Olivier Poitrey on 27/09/11.
//  Copyright 2011 Dailymotion. All rights reserved.
//

#import "DetailViewController.h"
#import "RootViewController.h"

NSString *formatTime(float time);
NSString *formatTime(float time)
{
    long seconds = (long)time;
    
    long hour = floor(seconds / 3600);
    long min = floor(seconds / 60);
    min %= 60;
    long sec = seconds % 60;

    if (seconds < 3600)
    {
        return [NSString stringWithFormat:@"%02ld:%02ld", min, sec];
    }
    else
    {
        return [NSString stringWithFormat:@"%02ldh%02ld", hour, min];        
    }
}

@interface DetailViewController ()
@property (nonatomic, retain) UIPopoverController *popoverController;
@property (nonatomic, retain) DailymotionPlayerViewController *playerController;
- (void)configureView;
@end

@implementation DetailViewController

@synthesize toolbar = _toolbar;
@synthesize detailItem = _detailItem;
@synthesize videoView = _videoView;
@synthesize console = _console;
@synthesize volume = _volume;
@synthesize currentTime = _currentTime;
@synthesize duration = _duration;
@synthesize popoverController = _myPopoverController;
@synthesize playerController = _playerController;

#pragma mark - Managing the detail item

/*
 When setting the detail item, update the view and dismiss the popover controller if it's showing.
 */
- (void)setDetailItem:(id)newDetailItem
{
    if (_detailItem != newDetailItem)
    {
        [_detailItem release];
        _detailItem = [newDetailItem retain];
        
        // Update the view.
        [self configureView];
    }

    if (self.popoverController != nil)
    {
        [self.popoverController dismissPopoverAnimated:YES];
    }        
}

- (void)configureView
{
    if (_playerController)
    {
        [_playerController load:[_detailItem objectForKey:@"id"]];
    }
    else
    {
        //Dailymotion.WebEndpoint = @"http://stage-01.dailymotion.com";
        _playerController = [[DailymotionPlayerViewController alloc]
                             initWithVideo:[_detailItem objectForKey:@"id"]
                                    params:[NSDictionary dictionaryWithObject:[NSNumber numberWithBool:YES] forKey:@"autoplay"]];
        _playerController.delegate = self;
        _playerController.view.frame = self.videoView.bounds;
        [self.videoView addSubview:_playerController.view];
    }
}

- (void)dailymotionPlayer:(DailymotionPlayerViewController *)player didReceiveEvent:(NSString *)eventName
{
    NSMutableString *event = [eventName mutableCopy];
    if ([eventName isEqualToString:@"durationchange"])
    {
        _duration.text = formatTime(_playerController.duration);
        [event appendFormat:@" time=%f", _playerController.duration];
    }
    else if ([eventName isEqualToString:@"timeupdate"])
    {
        _currentTime.text = formatTime(_playerController.currentTime);
        [event appendFormat:@" duration=%f", _playerController.currentTime];
    }
    else if ([eventName isEqualToString:@"progress"])
    {
        [event appendFormat:@" time=%f", _playerController.bufferedTime];
    }

    _console.text = [NSString stringWithFormat:@"-> %@\n%@", event, [_console.text substringToIndex:MIN(1000, _console.text.length)]];
}

- (IBAction)togglePlay:(id)sender
{
    [_playerController togglePlay];
}

- (IBAction)play:(id)sender
{
    [_playerController play];
}

- (IBAction)pause:(id)sender
{
    [_playerController pause];
}

- (IBAction)fullscreen:(id)sender
{
    _playerController.fullscreen = YES;
}

- (IBAction)toggleMute:(id)sender
{
    // TODO
}

- (IBAction)mute:(id)sender
{
    _playerController.muted = YES;
}

- (IBAction)unmute:(id)sender
{
    _playerController.muted = NO;
}

- (IBAction)volume:(id)sender
{
    _playerController.volume = ((UISlider *)sender).value;
}


- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    return YES;
}

#pragma mark - Split view support

- (void)splitViewController:(UISplitViewController *)svc willHideViewController:(UIViewController *)aViewController withBarButtonItem:(UIBarButtonItem *)barButtonItem forPopoverController: (UIPopoverController *)pc
{
    barButtonItem.title = @"Events";
    NSMutableArray *items = [[self.toolbar items] mutableCopy];
    [items insertObject:barButtonItem atIndex:0];
    [self.toolbar setItems:items animated:YES];
    [items release];
    self.popoverController = pc;
}

// Called when the view is shown again in the split view, invalidating the button and popover controller.
- (void)splitViewController:(UISplitViewController *)svc willShowViewController:(UIViewController *)aViewController invalidatingBarButtonItem:(UIBarButtonItem *)barButtonItem
{
    NSMutableArray *items = [[self.toolbar items] mutableCopy];
    [items removeObjectAtIndex:0];
    [self.toolbar setItems:items animated:YES];
    [items release];
    self.popoverController = nil;
}

/*
 // Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad
{
    [super viewDidLoad];
}
 */

- (void)viewDidUnload
{
    [self setVideoView:nil];
    [self setVolume:nil];
    [self setConsole:nil];
    [self setVolume:nil];
    [self setCurrentTime:nil];
    [self setDuration:nil];
	[super viewDidUnload];

	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
	self.popoverController = nil;
}

#pragma mark - Memory management

- (void)didReceiveMemoryWarning
{
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)dealloc
{
    [_myPopoverController release];
    [_toolbar release];
    [_detailItem release];
    [_videoView release];
    _playerController.delegate = nil;
    [_playerController release];
    [_console release];
    [_volume release];
    [_currentTime release];
    [_duration release];
    [super dealloc];
}

@end
