//
//  RootViewController.m
//  Dailymotion Demo
//
//  Created by Olivier Poitrey on 27/09/11.
//  Copyright 2011 Dailymotion. All rights reserved.
//

#import "RootViewController.h"
#import "DetailViewController.h"
#import "UIImageView+WebCache.h"

@interface RootViewController ()
@property (nonatomic, retain) Dailymotion *api;
@property (nonatomic, retain) NSArray *videos;
@end

@implementation RootViewController
		
@synthesize detailViewController;
@synthesize api = _api;
@synthesize videos = _videos;

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.clearsSelectionOnViewWillAppear = NO;
    self.contentSizeForViewInPopover = CGSizeMake(320.0, 600.0);
    self.tableView.rowHeight = 60.0;

    self.videos = [NSArray array];
    self.api = [[Dailymotion alloc] init];
    NSDictionary *args = [NSDictionary dictionaryWithObjectsAndKeys:
                          [NSArray arrayWithObjects:@"id", @"title", @"owner.screenname", @"thumbnail_small_url", nil], @"fields",
                          @"featured", @"filters",
                          @"fr", @"localization",
                          @"music", @"channel",
                          [NSNumber numberWithInt:40], @"limit",
                          nil];
    [_api request:@"/videos" withArguments:args delegate:self];
}

- (void)dailymotion:(Dailymotion *)dailymotion didReturnResult:(NSDictionary *)result userInfo:(NSDictionary *)userInfo
{
    self.videos = [result objectForKey:@"list"];
    [self.tableView reloadData];
}


- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
}

- (void)viewWillDisappear:(BOOL)animated
{
	[super viewWillDisappear:animated];
}

- (void)viewDidDisappear:(BOOL)animated
{
	[super viewDidDisappear:animated];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return YES;
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

		
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return _videos.count;    		
}
		
- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"video";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil)
    {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier] autorelease];
    }
    
    NSDictionary *video = [_videos objectAtIndex:indexPath.row];
    cell.textLabel.text = [video objectForKey:@"title"];
    cell.detailTextLabel.text = [video objectForKey:@"owner.screenname"];
    [cell.imageView setImageWithURL:[NSURL URLWithString:[video objectForKey:@"thumbnail_small_url"]]
                   placeholderImage:[UIImage imageNamed:@"placeholder.png"]];
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    detailViewController.detailItem = [_videos objectAtIndex:indexPath.row];
}

- (void)dealloc
{
    [detailViewController release];
    [_api release];
    [_videos release];
    [super dealloc];
}

@end
